@@ -76,57 +76,63 @@ gboolean expose_parent(GtkWidget * widget, GdkEventExpose * event) {
     color.alpha = 0;
 
     XRenderFillRectangle(GDK_DISPLAY(), PictOpSrc, picture, &color,
-                         0, 0,
-                         widget->allocation.width,
-                         widget->allocation.height);
+                             0, 0,
+                             widget->allocation.width,
+                             widget->allocation.height);
 
-    radius = app->config->corner_radius;
-    cr = gdk_cairo_create(drawable);
-    cairo_set_source_rgba(cr,
-                          (double)app->config->background_color.red /
-                          (MAXSHORT * 2 + 1),
-                          (double)app->config->background_color.green /
-                          (MAXSHORT * 2 + 1),
-                          (double)app->config->background_color.blue /
-                          (MAXSHORT * 2 + 1),
-                          (double)app->config->alpha_comp / 100);
+    if (app->config->icons_layout < PRESET_NOW){
 
-    width = plugin->clip.width;
-    height = plugin->clip.height;
-    x = plugin->clip.x;
-    y = plugin->clip.y;
+        radius = app->config->corner_radius;
+        cr = gdk_cairo_create(drawable);
+        cairo_set_source_rgba(cr,
+                              (double)app->config->background_color.red /
+                              (MAXSHORT * 2 + 1),
+                              (double)app->config->background_color.green /
+                              (MAXSHORT * 2 + 1),
+                              (double)app->config->background_color.blue /
+                              (MAXSHORT * 2 + 1),
+                              (double)app->config->alpha_comp / 100);
 
-    if ((radius > height / 2) || (radius > width / 2)) {
-        if (width < height) {
-            radius = width / 2 - 1;
-        } else {
-            radius = height / 2 - 2;
+        width = plugin->clip.width;
+        height = plugin->clip.height;
+        x = plugin->clip.x;
+        y = plugin->clip.y;
+
+        if ((radius > height / 2) || (radius > width / 2)) {
+            if (width < height) {
+                radius = width / 2 - 1;
+            } else {
+                radius = height / 2 - 2;
+            }
         }
+
+        cairo_move_to(cr, x + radius, y);
+        cairo_line_to(cr, x + width - radius, y);
+        cairo_curve_to(cr, x + width - radius, y, x + width, y, x + width,
+                       y + radius);
+        cairo_line_to(cr, x + width, y + height - radius);
+        cairo_curve_to(cr, x + width, y + height - radius, x + width,
+                       y + height, x + width - radius, y + height);
+        cairo_line_to(cr, x + radius, y + height);
+        cairo_curve_to(cr, x + radius, y + height, x, y + height, x,
+                       y + height - radius);
+        cairo_line_to(cr, x, y + radius);
+        cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
+
+        cairo_fill(cr);
+
+        XFixesDestroyRegion(GDK_DISPLAY(), region);
+        XRenderFreePicture(GDK_DISPLAY(), picture);
+
+        cairo_destroy(cr);
     }
-  
-    cairo_move_to(cr, x + radius, y);
-    cairo_line_to(cr, x + width - radius, y);
-    cairo_curve_to(cr, x + width - radius, y, x + width, y, x + width,
-                   y + radius);
-    cairo_line_to(cr, x + width, y + height - radius);
-    cairo_curve_to(cr, x + width, y + height - radius, x + width,
-                   y + height, x + width - radius, y + height);
-    cairo_line_to(cr, x + radius, y + height);
-    cairo_curve_to(cr, x + radius, y + height, x, y + height, x,
-                   y + height - radius);
-    cairo_line_to(cr, x, y + radius);
-    cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
-
-    cairo_fill(cr);
-
-    XFixesDestroyRegion(GDK_DISPLAY(), region);
-    XRenderFreePicture(GDK_DISPLAY(), picture);
-
     if (plugin->queueRefresh) {
         redraw_home_window(TRUE);
         plugin->queueRefresh = FALSE;
     }
-    cairo_destroy(cr);
+
+     
+        
     return
         GTK_WIDGET_CLASS(g_type_class_peek_parent
                          (GTK_FRAME_GET_CLASS(widget)))->expose_event
@@ -183,50 +189,52 @@ omweather_plugin_expose_event(GtkWidget * widget, GdkEventExpose * event) {
     /* Free context */
     cairo_destroy (cr);
 
-    radius = app->config->corner_radius;
-    cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
-    cairo_set_source_rgba(cr,
-                          (double)app->config->background_color.red /
-                          (MAXSHORT * 2 + 1),
-                          (double)app->config->background_color.green /
-                          (MAXSHORT * 2 + 1),
-                          (double)app->config->background_color.blue /
-                          (MAXSHORT * 2 + 1),
-                          (double)app->config->alpha_comp / 100);
+    if (app->config->icons_layout < PRESET_NOW){
+        radius = app->config->corner_radius;
+        cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
+        cairo_set_source_rgba(cr,
+                              (double)app->config->background_color.red /
+                              (MAXSHORT * 2 + 1),
+                              (double)app->config->background_color.green /
+                              (MAXSHORT * 2 + 1),
+                              (double)app->config->background_color.blue /
+                              (MAXSHORT * 2 + 1),
+                              (double)app->config->alpha_comp / 100);
 
-    width = event->area.width;
-    height = event->area.height;
-    x = event->area.x;
-    y = event->area.y;
+        width = event->area.width;
+        height = event->area.height;
+        x = event->area.x;
+        y = event->area.y;
 
-    if ((radius > height / 2) || (radius > width / 2)) {
-        if (width < height) {
-            radius = width / 2 - 1;
-        } else {
-            radius = height / 2 - 2;
+        if ((radius > height / 2) || (radius > width / 2)) {
+            if (width < height) {
+                radius = width / 2 - 1;
+            } else {
+                radius = height / 2 - 2;
+            }
         }
+
+        cairo_move_to(cr, x + radius, y);
+        cairo_line_to(cr, x + width - radius, y);
+        cairo_curve_to(cr, x + width - radius, y, x + width, y, x + width,
+                       y + radius);
+        cairo_line_to(cr, x + width, y + height - radius);
+        cairo_curve_to(cr, x + width, y + height - radius, x + width,
+                       y + height, x + width - radius, y + height);
+        cairo_line_to(cr, x + radius, y + height);
+        cairo_curve_to(cr, x + radius, y + height, x, y + height, x,
+                       y + height - radius);
+        cairo_line_to(cr, x, y + radius);
+        cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
+
+        /* Draw alpha background */
+        cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+
+        cairo_fill(cr);
+        cairo_destroy(cr);
     }
-
-    cairo_move_to(cr, x + radius, y);
-    cairo_line_to(cr, x + width - radius, y);
-    cairo_curve_to(cr, x + width - radius, y, x + width, y, x + width,
-                   y + radius);
-    cairo_line_to(cr, x + width, y + height - radius);
-    cairo_curve_to(cr, x + width, y + height - radius, x + width,
-                   y + height, x + width - radius, y + height);
-    cairo_line_to(cr, x + radius, y + height);
-    cairo_curve_to(cr, x + radius, y + height, x, y + height, x,
-                   y + height - radius);
-    cairo_line_to(cr, x, y + radius);
-    cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
-
-    /* Draw alpha background */
-    cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-
-    cairo_fill(cr);
-    cairo_destroy(cr);
     return GTK_WIDGET_CLASS(g_type_class_peek_parent
                          (GTK_FRAME_GET_CLASS(widget)))->expose_event(widget, event);
 
 }
-#endif
\ No newline at end of file
+#endif
